@@ -86,7 +86,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
             if self.data.get('condiciones_pago'):
                 dom.setAttribute('CondicionesDePago', self.data.get('condiciones_pago'))
 
-            if self.data.get('descuento') not in ['0', '0.00', '0.000000']:
+            if self.data.get('descuento') and self.data.get('descuento') not in ['0', '0.00', '0.000000']:
                 dom.setAttribute('Descuento', self.data.get('descuento'))
 
             dom.setAttribute('MetodoPago', self.data.get('metodo_pago'))
@@ -441,7 +441,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 cfdi_concepto.setAttribute('Descripcion', replace(concepto.get('descripcion', '').strip()))
                 cfdi_concepto.setAttribute('ValorUnitario', str(concepto.get('valor_unitario')))
                 cfdi_concepto.setAttribute('Importe', str(concepto.get('importe')))
-                if concepto.get('descuento') not in ['0', '0.00', '0.000000'] :
+                if concepto.get('descuento') and concepto.get('descuento') not in ['0', '0.00', '0.000000'] :
                     cfdi_concepto.setAttribute('Descuento', str(concepto.get('descuento')))
                 cfdi_concepto.setAttribute('ObjetoImp', concepto.get('objeto_impuesto'))
 
